@@ -2,21 +2,28 @@ anova.DirichletRegModel <- function(object, ..., sorted = FALSE) {
 
   comp.objs <- list(object, ...)
 
-  if(!all(unlist(lapply(comp.objs, class)) == "DirichletRegModel")) stop('only models fitted using "DirichReg()" can be compared.')
+  if(!all("DirichletRegModel" %in% unlist(lapply(comp.objs, class)))){
+    stop('only models fitted using "DirichReg()" can be compared.')
+  }
   for(i in seq_along(comp.objs)[-1L]){
-    if(!identical(comp.objs[[i-1L]][["Y"]], comp.objs[[i]][["Y"]])) stop("models appear not to be nested.")
+    if(!identical(comp.objs[[i-1L]][["Y"]], comp.objs[[i]][["Y"]])){
+      stop("models appear not to be nested.")
+    }
   }
 
-  n.mods <- length(comp.objs)
-  n.pars <- unlist(lapply(seq_len(n.mods), function(i){ comp.objs[[i]]$npar }))
-  calls <- lapply(seq_len(n.mods), function(i) comp.objs[[i]]$call)
-  sorting <- if(sorted){ order(n.pars, decreasing=TRUE) } else { seq_len(n.mods) }
-
+  n.mods  <- length(comp.objs)
+  n.pars  <- unlist(lapply(comp.objs, `[[`, "npar"))
+  calls   <- unlist(lapply(comp.objs, `[[`, "call"))
+  sorting <- if(sorted){
+               order(n.pars, decreasing = TRUE)
+             } else {
+               seq_len(n.mods)
+             }
   comp.objs <- comp.objs[sorting]
 
-  deviances <- unlist(lapply(seq_len(n.mods), function(i){ -2*comp.objs[[i]]$logLik }))
+  deviances <- -2 * unlist(lapply(comp.objs, `[[`, "logLik"))
   dev_diffs <- abs(c(NA, deviances[1L] - deviances[-1L]))
-  df <- abs(c(NA, n.pars[1L] - n.pars[-1L]))
+  df        <- abs(c(NA, n.pars[1L] - n.pars[-1L]))
 
   res <- structure(list(
     "Deviance"   = deviances,
@@ -29,8 +36,7 @@ anova.DirichletRegModel <- function(object, ..., sorted = FALSE) {
     "calls"      = calls
   ), class = "anova_DirichletRegModel")
 
-  print(res)
-  invisible(res)
+  return(res)
 
 }
 
@@ -42,11 +48,12 @@ print.anova_DirichletRegModel <- function(x, ...){
 
   writeLines("Analysis of Deviance Table\n")
 
-  model_numbers <- unlist(lapply(format(x$sorting), function(i){ paste0("Model ", i) }))
-  model_names <- unlist(lapply(x$sorting, function(i){ deparse(x$call[[i]], width.cutoff=500L) }))
+  model_numbers <- sprintf("Model %s", format(x$sorting))
+  model_names   <- unlist(lapply(x$call[x$sorting], deparse_nocutoff))
 
   for(i in seq_len(x$n.mods)){
-    writeLines(strwrap(paste0(model_numbers[[i]], ": ", model_names[[i]]), width=getOption("width"), exdent = 2L))
+    writeLines(strwrap(paste0(model_numbers[[i]], ": ", model_names[[i]]),
+      width = getOption("width") - 2L, exdent = 2L))
   }
 
   writeLines("")
@@ -57,6 +64,6 @@ print.anova_DirichletRegModel <- function(x, ...){
 
   printCoefmat(res, cs.ind = 1L, tst.ind = 3L, P.values = TRUE, na.print = "")
 
-  writeLines("")
+  if(interactive()) writeLines("")
 
 }
