@@ -2,13 +2,15 @@ coef.DirichletRegModel <- function(object, type = c("both", "beta", "gamma"), ..
 
   type <- match.arg(type, c("both", "beta", "gamma"))
 
-  cc <- object$coefficients
+  cc        <- object$coefficients
   names(cc) <- object$coefnames
 
   if(object$parametrization == "common"){
 
     ind <- cumsum(c(1L, object$n.vars))
-    cc <- lapply(seq_along(ind)[-1L], function(i) cc[seq.int(from = ind[i - 1L], to = ind[i] - 1L)])
+    cc  <- lapply(seq_along(ind)[-1L], function(i){
+             cc[seq.int(from = ind[i - 1L], to = ind[i] - 1L)]
+           })
     names(cc) <- object$varnames
     return(cc)
 
@@ -28,10 +30,11 @@ coef.DirichletRegModel <- function(object, type = c("both", "beta", "gamma"), ..
       }
     }
     names(bb) <- c(object$varnames)
+
     gg <- list("gamma" = cc[seq.int(from = length(cc) - ncol(object$Z) + 1L, to = length(cc))])
 
     if(type == "both"){
-      return(list("beta"=bb, "gamma"=gg))
+      return(list("beta" = bb, "gamma" = gg))
     } else if(type == "beta"){
       return(bb)
     } else if(type == "gamma"){
