@@ -1,3 +1,3 @@
 vcov.DirichletRegModel <- function(object, ...){
-  solve(-object$hessian)
-}
\ No newline at end of file
+  object$vcov
+}
